==> phoenix-starter-bpmn-0.1.1.9-20240529.020441-1-sources.jar: com/elitesland/cbpl/bpmn/registrar/task/BpmnInstanceDeletionTask.java <==
package com.elitesland.cbpl.bpmn.registrar.task;

import com.elitesland.cbpl.bpmn.data.service.TaskDefineService;
import com.elitesland.cbpl.bpmn.data.service.TaskInstanceService;
import com.elitesland.cbpl.bpmn.data.vo.param.TaskDefineQueryParamVO;
import com.elitesland.cbpl.bpmn.data.vo.param.TaskInstanceDeleteParamVO;
import com.elitesland.cbpl.common.constant.PublishStatus;
import com.elitesland.cbpl.scheduling.data.vo.param.ScheduleConfigSaveParamVO;
import com.elitesland.cbpl.scheduling.spi.SchedulingDeletionSpi;
import com.elitesland.cbpl.scheduling.spi.SchedulingRegistrarSpi;
import com.elitesland.cbpl.scheduling.util.SchedulingUtil;
import com.elitesland.cbpl.unicom.annotation.UnicomTag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

import static com.elitesland.cbpl.bpmn.config.BpmnProperties.BPMN_DELETION_CRON;
import static com.elitesland.cbpl.bpmn.config.BpmnProperties.BPMN_ENABLED;
import static com.elitesland.cbpl.scheduling.constant.InstanceStatus.*;
import static com.elitesland.cbpl.scheduling.util.SchedulingParamUtil.deletionParamInit;

/**
 * @author eric.hao
 * @since 2024/05/11
 */
@Slf4j
@RequiredArgsConstructor
@UnicomTag("__BpmnInstanceDeletionTask")
public class BpmnInstanceDeletionTask implements SchedulingRegistrarSpi, SchedulingDeletionSpi {

    private final TaskDefineService defineService;
    private final TaskInstanceService instanceService;

    @Override
    public boolean autoRegister() {
        return BPMN_ENABLED;
    }

    /**
     * 构建定时任务
     */
    @Override
    public ScheduleConfigSaveParamVO registerTask() {
        return deletionParamInit(this.getClass(), "流程编排实例-定时删除", BPMN_DELETION_CRON);
    }

    @Override
    public void deletion() {
        // 所有未删除的任务
        TaskDefineQueryParamVO query = new TaskDefineQueryParamVO();
        query.setVersionStatus(PublishStatus.EFFECTIVE.getCode());
        var tasks = defineService.taskDefineByParam(query);
        for (var task : tasks) {
            if (task.noDeletion()) {
                logger.warn("[PHOENIX-BPMN] {} deletion strategy: {}", task.getTaskCode(), task.getDeletionStrategyName());
                continue;
            }
            var deleteParam = new TaskInstanceDeleteParamVO();
            deleteParam.setTaskCode(task.getTaskCode());
            // 完成、异常中断、手动终止
            deleteParam.setInstanceStatus(List.of(COMPLETE.getCode(), INTERRUPT.getCode(), STOP.getCode()));
            deleteParam.setBeforeTime(SchedulingUtil.minusDays(task.getDeletionStrategy()));
            instanceService.deleteInstance(deleteParam, "AUTO");
        }
    }
}

==> phoenix-starter-bpmn-0.1.4.2-20240809.072750-1-sources.jar: com/elitesland/cbpl/bpmn/registrar/task/BpmnInstanceDeletionTask.java <==
package com.elitesland.cbpl.bpmn.registrar.task;

import com.elitesland.cbpl.bpmn.data.service.TaskDefineService;
import com.elitesland.cbpl.bpmn.data.service.TaskInstanceService;
import com.elitesland.cbpl.bpmn.data.vo.param.TaskDefineQueryParamVO;
import com.elitesland.cbpl.bpmn.data.vo.param.TaskInstanceDeleteParamVO;
import com.elitesland.cbpl.common.constant.PublishStatus;
import com.elitesland.cbpl.logging.common.data.vo.param.TrackDocDeleteParamVO;
import com.elitesland.cbpl.logging.common.pipeline.PipelineService;
import com.elitesland.cbpl.logging.common.util.LogConfigUtil;
import com.elitesland.cbpl.scheduling.data.vo.param.ScheduleConfigSaveParamVO;
import com.elitesland.cbpl.scheduling.spi.SchedulingDeletionSpi;
import com.elitesland.cbpl.scheduling.spi.SchedulingRegistrarSpi;
import com.elitesland.cbpl.scheduling.util.SchedulingUtil;
import com.elitesland.cbpl.unicom.annotation.UnicomTag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

import static com.elitesland.cbpl.bpmn.config.BpmnProperties.BPMN_DELETION_CRON;
import static com.elitesland.cbpl.bpmn.config.BpmnProperties.BPMN_ENABLED;
import static com.elitesland.cbpl.logging.common.config.LoggingProperties.LOG_SYSLOG_CFG;
import static com.elitesland.cbpl.rosefinch.constant.InstanceStatus.*;
import static com.elitesland.cbpl.scheduling.util.SchedulingParamUtil.deletionParamInit;

/**
 * @author eric.hao
 * @since 2024/05/11
 */
@Slf4j
@RequiredArgsConstructor
@UnicomTag("__BpmnInstanceDeletionTask")
public class BpmnInstanceDeletionTask implements SchedulingRegistrarSpi, SchedulingDeletionSpi {

    private final TaskDefineService defineService;
    private final TaskInstanceService instanceService;
    private final PipelineService pipelineService;

    @Override
    public boolean autoRegister() {
        return BPMN_ENABLED;
    }

    /**
     * 构建定时任务
     */
    @Override
    public ScheduleConfigSaveParamVO registerTask() {
        return deletionParamInit(this.getClass(), "流程编排实例-定时删除", BPMN_DELETION_CRON);
    }

    @Override
    public void deletion() {
        // 所有未删除的任务
        TaskDefineQueryParamVO query = new TaskDefineQueryParamVO();
        query.setVersionStatus(PublishStatus.EFFECTIVE.getCode());
        var tasks = defineService.taskDefineByParam(query);
        for (var task : tasks) {
            if (task.noDeletion()) {
                logger.warn("[BPMN] {} deletion strategy: {}", task.getTaskCode(), task.getDeletionStrategyName());
                continue;
            }
            var deleteParam = new TaskInstanceDeleteParamVO();
            deleteParam.setTaskCode(task.getTaskCode());
            // 完成、异常中断、手动终止
            deleteParam.setInstanceStatus(List.of(COMPLETE.getCode(), INTERRUPT.getCode(), STOP.getCode()));
            deleteParam.setBeforeTime(SchedulingUtil.minusDays(task.getDeletionStrategy()));
            List<String> traceIds = instanceService.deleteInstance(deleteParam, "AUTO");
            // 删除明细中的系统日志
            TrackDocDeleteParamVO trackDeleteParam = new TrackDocDeleteParamVO();
            trackDeleteParam.setTraceIds(traceIds);
            LogConfigUtil.supply(() -> pipelineService.trackDocDelete(trackDeleteParam), LOG_SYSLOG_CFG);
        }
    }
}
